@@ -9,8 +9,8 @@
 #
 package Test::Moose::More;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.036-0-gd30d56e
-$Test::Moose::More::VERSION = '0.037';
+# git description: 0.037-3-g7fcead6
+$Test::Moose::More::VERSION = '0.038';
 
 # ABSTRACT: More tools for testing Moose packages
 
@@ -105,6 +105,7 @@ sub does_ok {
     $roles     = [ $roles ] unless ref $roles;
     $message ||= _thing_name($thing, $thing_meta) . ' does %s';
 
+    BEGIN { warnings::unimport 'redundant' if $^V gt v5.21.1 }
     $tb->ok(!!$thing_meta->does_role($_), sprintf($message, $_))
         for @$roles;
 
@@ -120,6 +121,7 @@ sub does_not_ok {
     $roles     = [ $roles ] unless ref $roles;
     $message ||= _thing_name($thing, $thing_meta) . ' does not do %s';
 
+    BEGIN { warnings::unimport 'redundant' if $^V gt v5.21.1 }
     $tb->ok(!$thing_meta->does_role($_), sprintf($message, $_))
         for @$roles;
 
@@ -607,7 +609,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.037 of Test::Moose::More - released January 31, 2016 as part of Test-Moose-More.
+This document describes version 0.038 of Test::Moose::More - released June 22, 2016 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
